==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/Eslint.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Represents eslint configuration.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.833Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.Eslint")
public class Eslint extends io.github.cdklabs.projen.Component {

    protected Eslint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Eslint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Eslint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.EslintOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Returns the singletone Eslint component of a project or undefined if there is none.
     * <p>
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.Eslint of(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.javascript.Eslint.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.Eslint.class), new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Do not lint these files.
     * <p>
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addIgnorePattern(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addIgnorePattern", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Add an eslint override.
     * <p>
     * @param override This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addOverride(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.EslintOverride override) {
        software.amazon.jsii.Kernel.call(this, "addOverride", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(override, "override is required") });
    }

    /**
     * (experimental) Add an eslint rule.
     * <p>
     * @param rules This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRules(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> rules) {
        software.amazon.jsii.Kernel.call(this, "addRules", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(rules, "rules is required") });
    }

    /**
     * (experimental) Add a glob file pattern which allows importing dev dependencies.
     * <p>
     * @param pattern glob pattern. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void allowDevDeps(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "allowDevDeps", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Direct access to the eslint configuration (escape hatch).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Object getConfig() {
        return software.amazon.jsii.Kernel.get(this, "config", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * (experimental) File patterns that should not be linted.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getIgnorePatterns() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "ignorePatterns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) eslint overrides.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.javascript.EslintOverride> getOverrides() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "overrides", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.EslintOverride.class))));
    }

    /**
     * (experimental) eslint rules.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.util.List<java.lang.Object>> getRules() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "rules", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)))));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.Eslint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.Eslint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.javascript.EslintOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.javascript.EslintOptions.Builder();
        }

        /**
         * (experimental) Directories with source files to lint (e.g. [ "src" ]).
         * <p>
         * @return {@code this}
         * @param dirs Directories with source files to lint (e.g. [ "src" ]). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dirs(final java.util.List<java.lang.String> dirs) {
            this.options.dirs(dirs);
            return this;
        }

        /**
         * (experimental) Enable import alias for module paths.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param aliasExtensions Enable import alias for module paths. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder aliasExtensions(final java.util.List<java.lang.String> aliasExtensions) {
            this.options.aliasExtensions(aliasExtensions);
            return this;
        }

        /**
         * (experimental) Enable import alias for module paths.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param aliasMap Enable import alias for module paths. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder aliasMap(final java.util.Map<java.lang.String, java.lang.String> aliasMap) {
            this.options.aliasMap(aliasMap);
            return this;
        }

        /**
         * (experimental) Directories with source files that include tests and build tools.
         * <p>
         * These
         * sources are linted but may also import packages from <code>devDependencies</code>.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param devdirs Directories with source files that include tests and build tools. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder devdirs(final java.util.List<java.lang.String> devdirs) {
            this.options.devdirs(devdirs);
            return this;
        }

        /**
         * (experimental) File types that should be linted (e.g. [ ".js", ".ts" ]).
         * <p>
         * Default: [".ts"]
         * <p>
         * @return {@code this}
         * @param fileExtensions File types that should be linted (e.g. [ ".js", ".ts" ]). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileExtensions(final java.util.List<java.lang.String> fileExtensions) {
            this.options.fileExtensions(fileExtensions);
            return this;
        }

        /**
         * (experimental) List of file patterns that should not be linted, using the same syntax as .gitignore patterns.
         * <p>
         * Default: [ '*.js', '*.d.ts', 'node_modules/', '*.generated.ts', 'coverage' ]
         * <p>
         * @return {@code this}
         * @param ignorePatterns List of file patterns that should not be linted, using the same syntax as .gitignore patterns. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ignorePatterns(final java.util.List<java.lang.String> ignorePatterns) {
            this.options.ignorePatterns(ignorePatterns);
            return this;
        }

        /**
         * (experimental) Should we lint .projenrc.js.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param lintProjenRc Should we lint .projenrc.js. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lintProjenRc(final java.lang.Boolean lintProjenRc) {
            this.options.lintProjenRc(lintProjenRc);
            return this;
        }

        /**
         * (experimental) Enable prettier for code formatting.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param prettier Enable prettier for code formatting. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder prettier(final java.lang.Boolean prettier) {
            this.options.prettier(prettier);
            return this;
        }

        /**
         * (experimental) Always try to resolve types under `<root>@types` directory even it doesn't contain any source code.
         * <p>
         * This prevents <code>import/no-unresolved</code> eslint errors when importing a <code>&#64;types/*</code> module that would otherwise remain unresolved.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param tsAlwaysTryTypes Always try to resolve types under `<root>@types` directory even it doesn't contain any source code. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsAlwaysTryTypes(final java.lang.Boolean tsAlwaysTryTypes) {
            this.options.tsAlwaysTryTypes(tsAlwaysTryTypes);
            return this;
        }

        /**
         * (experimental) Path to `tsconfig.json` which should be used by eslint.
         * <p>
         * Default: "./tsconfig.json"
         * <p>
         * @return {@code this}
         * @param tsconfigPath Path to `tsconfig.json` which should be used by eslint. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.javascript.Eslint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.Eslint build() {
            return new io.github.cdklabs.projen.javascript.Eslint(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/Eslint.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Represents eslint configuration.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.497Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.Eslint")
public class Eslint extends io.github.cdklabs.projen.Component {

    protected Eslint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Eslint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Eslint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.EslintOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Returns the singletone Eslint component of a project or undefined if there is none.
     * <p>
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.Eslint of(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.javascript.Eslint.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.Eslint.class), new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Adds an <code>extends</code> item to the eslint configuration.
     * <p>
     * @param extendList The list of "extends" to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addExtends(final @org.jetbrains.annotations.NotNull java.lang.String... extendList) {
        software.amazon.jsii.Kernel.call(this, "addExtends", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(extendList).toArray(Object[]::new));
    }

    /**
     * (experimental) Do not lint these files.
     * <p>
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addIgnorePattern(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addIgnorePattern", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Add a file, glob pattern or directory with source files to lint (e.g. [ "src" ]).
     * <p>
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addLintPattern(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addLintPattern", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Add an eslint override.
     * <p>
     * @param override This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addOverride(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.EslintOverride override) {
        software.amazon.jsii.Kernel.call(this, "addOverride", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(override, "override is required") });
    }

    /**
     * (experimental) Adds an eslint plugin.
     * <p>
     * @param plugins The names of plugins to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addPlugins(final @org.jetbrains.annotations.NotNull java.lang.String... plugins) {
        software.amazon.jsii.Kernel.call(this, "addPlugins", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(plugins).toArray(Object[]::new));
    }

    /**
     * (experimental) Add an eslint rule.
     * <p>
     * @param rules This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRules(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> rules) {
        software.amazon.jsii.Kernel.call(this, "addRules", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(rules, "rules is required") });
    }

    /**
     * (experimental) Add a glob file pattern which allows importing dev dependencies.
     * <p>
     * @param pattern glob pattern. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void allowDevDeps(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "allowDevDeps", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Direct access to the eslint configuration (escape hatch).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Object getConfig() {
        return software.amazon.jsii.Kernel.get(this, "config", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * (experimental) eslint task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getEslintTask() {
        return software.amazon.jsii.Kernel.get(this, "eslintTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) File patterns that should not be linted.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getIgnorePatterns() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "ignorePatterns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) Returns an immutable copy of the lintPatterns being used by this eslint configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getLintPatterns() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "lintPatterns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) eslint overrides.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.javascript.EslintOverride> getOverrides() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "overrides", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.EslintOverride.class))));
    }

    /**
     * (experimental) eslint rules.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.util.List<java.lang.Object>> getRules() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "rules", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)))));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.Eslint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.Eslint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.javascript.EslintOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.javascript.EslintOptions.Builder();
        }

        /**
         * (experimental) Files or glob patterns or directories with source files to lint (e.g. [ "src" ]).
         * <p>
         * @return {@code this}
         * @param dirs Files or glob patterns or directories with source files to lint (e.g. [ "src" ]). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dirs(final java.util.List<java.lang.String> dirs) {
            this.options.dirs(dirs);
            return this;
        }

        /**
         * (experimental) Enable import alias for module paths.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param aliasExtensions Enable import alias for module paths. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder aliasExtensions(final java.util.List<java.lang.String> aliasExtensions) {
            this.options.aliasExtensions(aliasExtensions);
            return this;
        }

        /**
         * (experimental) Enable import alias for module paths.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param aliasMap Enable import alias for module paths. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder aliasMap(final java.util.Map<java.lang.String, java.lang.String> aliasMap) {
            this.options.aliasMap(aliasMap);
            return this;
        }

        /**
         * (experimental) Files or glob patterns or directories with source files that include tests and build tools.
         * <p>
         * These sources are linted but may also import packages from <code>devDependencies</code>.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param devdirs Files or glob patterns or directories with source files that include tests and build tools. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder devdirs(final java.util.List<java.lang.String> devdirs) {
            this.options.devdirs(devdirs);
            return this;
        }

        /**
         * (experimental) File types that should be linted (e.g. [ ".js", ".ts" ]).
         * <p>
         * Default: [".ts"]
         * <p>
         * @return {@code this}
         * @param fileExtensions File types that should be linted (e.g. [ ".js", ".ts" ]). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileExtensions(final java.util.List<java.lang.String> fileExtensions) {
            this.options.fileExtensions(fileExtensions);
            return this;
        }

        /**
         * (experimental) List of file patterns that should not be linted, using the same syntax as .gitignore patterns.
         * <p>
         * Default: [ '*.js', '*.d.ts', 'node_modules/', '*.generated.ts', 'coverage' ]
         * <p>
         * @return {@code this}
         * @param ignorePatterns List of file patterns that should not be linted, using the same syntax as .gitignore patterns. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ignorePatterns(final java.util.List<java.lang.String> ignorePatterns) {
            this.options.ignorePatterns(ignorePatterns);
            return this;
        }

        /**
         * (deprecated) Should we lint .projenrc.js.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @deprecated set to <code>false</code> to remove any automatic rules and add manually
         * @param lintProjenRc Should we lint .projenrc.js. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder lintProjenRc(final java.lang.Boolean lintProjenRc) {
            this.options.lintProjenRc(lintProjenRc);
            return this;
        }

        /**
         * (deprecated) Projenrc file to lint.
         * <p>
         * Use empty string to disable.
         * <p>
         * Default: "projenrc.js"
         * <p>
         * @return {@code this}
         * @deprecated provide as <code>devdirs</code>
         * @param lintProjenRcFile Projenrc file to lint. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder lintProjenRcFile(final java.lang.String lintProjenRcFile) {
            this.options.lintProjenRcFile(lintProjenRcFile);
            return this;
        }

        /**
         * (experimental) Enable prettier for code formatting.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param prettier Enable prettier for code formatting. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder prettier(final java.lang.Boolean prettier) {
            this.options.prettier(prettier);
            return this;
        }

        /**
         * (experimental) Always try to resolve types under <code>&lt;root&gt;&#64;types</code> directory even it doesn't contain any source code.
         * <p>
         * This prevents <code>import/no-unresolved</code> eslint errors when importing a <code>&#64;types/*</code> module that would otherwise remain unresolved.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param tsAlwaysTryTypes Always try to resolve types under <code>&lt;root&gt;&#64;types</code> directory even it doesn't contain any source code. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsAlwaysTryTypes(final java.lang.Boolean tsAlwaysTryTypes) {
            this.options.tsAlwaysTryTypes(tsAlwaysTryTypes);
            return this;
        }

        /**
         * (experimental) Path to <code>tsconfig.json</code> which should be used by eslint.
         * <p>
         * Default: "./tsconfig.json"
         * <p>
         * @return {@code this}
         * @param tsconfigPath Path to <code>tsconfig.json</code> which should be used by eslint. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * (experimental) Write eslint configuration as YAML instead of JSON.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param yaml Write eslint configuration as YAML instead of JSON. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder yaml(final java.lang.Boolean yaml) {
            this.options.yaml(yaml);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.javascript.Eslint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.Eslint build() {
            return new io.github.cdklabs.projen.javascript.Eslint(
                this.project,
                this.options.build()
            );
        }
    }
}
